from django.http import HttpResponseRedirect, HttpResponse
from django.shortcuts import render_to_response, redirect, render, get_object_or_404
from django.template import RequestContext
from django.core.context_processors import csrf
from django.core.mail import send_mail
from .models import Contact



def contactForm(request):
	if request.method == 'POST':
		c = {}
		c.update(csrf(request))
		form = Contact(request.POST)
		if form.is_valid():
			message = form.cleaned_data['message']
			fromEmail = form.cleaned_data['email']
			send_mail('Email from Truck Form', message, fromEmail,
			    ['bryanlrobinson@gmail.com'], fail_silently=False)
			return HttpResponseRedirect('/thanks/')
			
	else:
		c = {}
		c.update(csrf(request))
		form = Contact()
	return render (request, 'contact.html', {
		'form': form,
		'c': c,
	})



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='simple-django-contact',
    version='0.1',
    packages=['simple-django-contact'],
    include_package_data=True,
    license='BSD License',  # example license
    description='A simple Django app to set up a contact form',
    long_description=README,
    url='http://bryanlrobinson.com/',
    author='Bryan L. Robinson',
    author_email='bryanlrobinson@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License', # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)